@@ -10,7 +10,7 @@ import sys
 
 from decorator import contextmanager
 
-__version__ = '0.13.11'
+__version__ = '0.13.12'
 
 from IPython import get_ipython
 from IPython.core.debugger import BdbQuit_excepthook
@@ -309,7 +309,7 @@ def main():
     while 1:
         try:
             import pdb as stdlib_pdb
-            if hasattr(stdlib_pdb, "_run"):
+            if hasattr(stdlib_pdb.Pdb, "_run"):
                 # Looks like Pdb from Python 3.11+
                 if run_as_module:
                     pdb._run(stdlib_pdb._ModuleTarget(mainpyfile))
